@@ -68,7 +68,7 @@ class ReproCheck(BaseModel):
         if not self.n_dvc_remotes:
             return (
                 "No DVC remotes have been defined. "
-                "Run `calkit config setup-remote` or `dvc remote add` next."
+                "Run `calkit config remote` or `dvc remote add` next."
             )
         if not self.has_pipeline:
             return (
@@ -180,7 +180,7 @@ def check_reproducibility(
     if log_func is None:
         log_func = print
     try:
-        repo = git.Repo(wdir)
+        git.Repo(wdir)
         res["is_git_repo"] = True
     except InvalidGitRepositoryError:
         res["is_git_repo"] = False
@@ -235,6 +235,7 @@ def check_reproducibility(
             and "conda run" not in cmd
             and "mamba run" not in cmd
             and "docker run" not in cmd
+            and "renv::restore()" not in cmd
         ):
             stages_no_env.append(stage_name)
         else:
